==> oscars_mgmnt_clms-0.0.8.dev20240411+45-py3-none-any.whl: oscars_mgmnt_clms/parser/geotiff.py <==
import os
import re
from typing import Tuple

import rasterio

from oscars_mgmnt_clms.file_object import ObjectInfo
from oscars_mgmnt_clms.parser.filename import FilenameParser, get_geometry, decode_platforms


class CLMSGlobalParser_GeoTIFF(FilenameParser):
    """Parser used to build GeoJSON metadata from CLMS Global Land products in netCDF format"""

    def __init__(self):
        super().__init__(template="CLMS_GLOBAL.template")

    def specific_treatment(self, product_file_info: ObjectInfo, values: dict):
        self.fix_products(product_file_info)

        # example of supported filenames:
        #   c_gls_LSP300-AMPL-S1_202301010000_GLOBE_OLCI_V1.0.1.tiff
        #   c_gls_LSP300-SOSD-S2_202301010000_GLOBE_OLCI_V1.0.1.tiff
        fn = os.path.abspath(product_file_info.get_product_path())
        file_name = os.path.basename(fn).rpartition(".")[0]
        file_name_parts = file_name.split("_")

        _, product_type, product_group = file_name_parts[2].split("-")
        values["productgroupid"] = product_group
        values["producttype"] = product_type
        version = file_name_parts[-1]
        values["productVersion"] = version

        with rasterio.open(fn) as raster:
            tags = raster.tags()
            values["id"] = file_name
            values["title"] = f"{tags['title']} - {', '.join(raster.descriptions)}"

            processingCenter = "VITO"
            if "institution" in tags:
                processingCenter = tags["institution"].split(",")[0].upper()
            values["processingCenter"] = (
                processingCenter.replace(" NV", "").replace(" GMBH", "").replace(" ", "_")
            )
            bbox = self.get_bbox(raster)
            (
                values["westbbox"],
                values["southbbox"],
                values["eastbbox"],
                values["northbbox"],
            ) = bbox
            values["geometry"] = get_geometry(bbox)
            values["platforms"] = decode_platforms(tags['platform'])
            if "time_coverage_start" in tags:
                values["beginposition"] = tags["time_coverage_start"]
                values["endposition"] = tags["time_coverage_end"]
            else:
                values["beginposition"] = values["nominaldatetime"]
                values["endposition"] = values["nominaldatetime"]

        values["tileid"] = file_name_parts[-3].replace("GLOBAL", "GLOBE")
        collection_dir = re.match(
            f"clms_global_([\\w.-]+)_{self.filetype}", values["parentidentifier"]
        ).group(1)
        resolution_regex = re.compile("([\\d.]+)(m|km)")
        regex_result = resolution_regex.match(collection_dir.split("_")[1])
        if regex_result:
            factor = 1000 if regex_result.group(2)[0] == "k" else 1
            values["resolution"] = int(float(regex_result.group(1)) * factor)
        else:
            values["resolution"] = None
        values["conformsto"] = "https://www.opengis.net/def/crs/EPSG/0/4326"

        return values["id"]

    def get_bbox(self, raster: rasterio.DatasetReader, rounding: int = 11) -> Tuple[float, float, float, float]:
        return tuple(round(c, rounding) for c in raster.bounds)

    @property
    def filetype(self) -> str:
        return "geotiff"

    @property
    def mimetype(self) -> str:
        return "image/tiff"

==> oscars_mgmnt_clms-0.1.0.dev20240423+51-py3-none-any.whl: oscars_mgmnt_clms/parser/geotiff.py <==
import os
import re
from typing import Tuple

import rasterio

from oscars_mgmnt_clms.file_object import ObjectInfo
from oscars_mgmnt_clms.parser.filename import (
    FilenameParser,
    get_geometry,
    decode_platforms,
    parse_date,
    format_date,
    fix_bbox,
)


class CLMSGlobalParser_GeoTIFF(FilenameParser):
    """Parser used to build GeoJSON metadata from CLMS Global Land products in netCDF format"""

    def __init__(self):
        super().__init__(template="CLMS_GLOBAL.template")

    def specific_treatment(self, product_file_info: ObjectInfo, values: dict):
        self.fix_products(product_file_info)

        # example of supported filenames:
        #   c_gls_LSP300-AMPL-S1_202301010000_GLOBE_OLCI_V1.0.1.tiff
        #   c_gls_LSP300-SOSD-S2_202301010000_GLOBE_OLCI_V1.0.1.tiff
        fn = os.path.abspath(product_file_info.get_product_path())
        file_name = os.path.basename(fn).rpartition(".")[0]
        file_name_parts = file_name.split("_")

        _, product_type, product_group = file_name_parts[2].split("-")
        values["productgroupid"] = product_group
        values["producttype"] = product_type
        version = file_name_parts[-1]
        values["productVersion"] = version

        with rasterio.open(fn) as raster:
            tags = raster.tags()
            values["id"] = file_name
            values["title"] = f"{tags['title']} - {', '.join(raster.descriptions)}"

            processingCenter = "VITO"
            if "institution" in tags:
                processingCenter = tags["institution"].split(",")[0].upper()
            values["processingCenter"] = (
                processingCenter.replace(" NV", "")
                .replace(" GMBH", "")
                .replace(" ", "_")
            )
            bbox = self.get_bbox(raster)
            (
                values["westbbox"],
                values["southbbox"],
                values["eastbbox"],
                values["northbbox"],
            ) = bbox
            values["geometry"] = get_geometry(bbox)
            values["platforms"] = decode_platforms(tags["platform"])
            if "time_coverage_start" in tags:
                values["beginposition"] = format_date(
                    parse_date(tags["time_coverage_start"])
                )
                values["endposition"] = format_date(
                    parse_date(tags["time_coverage_end"])
                )
            else:
                values["beginposition"] = values["nominaldatetime"]
                values["endposition"] = values["nominaldatetime"]

        values["tileid"] = file_name_parts[-3].replace("GLOBAL", "GLOBE")
        collection_dir = re.match(
            f"clms_global_([\\w.-]+)_{self.filetype}", values["parentidentifier"]
        ).group(1)
        resolution_regex = re.compile("([\\d.]+)(m|km)")
        regex_result = resolution_regex.match(collection_dir.split("_")[1])
        if regex_result:
            factor = 1000 if regex_result.group(2)[0] == "k" else 1
            values["resolution"] = int(float(regex_result.group(1)) * factor)
        else:
            values["resolution"] = None
        values["conformsto"] = "https://www.opengis.net/def/crs/EPSG/0/4326"

        return values["id"]

    def get_bbox(
        self, raster: rasterio.DatasetReader, rounding: int = 11
    ) -> Tuple[float, float, float, float]:
        return fix_bbox(raster.bounds, rounding, raster.width, raster.height)

    @property
    def filetype(self) -> str:
        return "geotiff"

    @property
    def mimetype(self) -> str:
        return "image/tiff"
